CommentConfig

Struct CommentConfig 

pub struct CommentConfig {
    pub line: Option<String>,
    pub block_start: Option<String>,
    pub block_end: Option<String>,
}
Comment tokens/config for a given language.

The editor kernel can use this to implement comment toggling in a UI-agnostic way.

Fields

line: Option<String>

Line comment token (e.g. //, #).

block_start: Option<String>

Block comment start token (e.g. /*).

block_end: Option<String>

Block comment end token (e.g. */).

Implementations

Source

impl CommentConfig

pub fn line(token: impl Into<String>) -> Self

Create a config that supports only line comments.

pub fn block(start: impl Into<String>, end: impl Into<String>) -> Self

Create a config that supports only block comments.

pub fn line_and_block( line: impl Into<String>, block_start: impl Into<String>, block_end: impl Into<String>, ) -> Self

Create a config that supports both line and block comments.

pub fn has_line(&self) -> bool

Returns true if a line comment token is configured.

pub fn has_block(&self) -> bool

Returns true if both block comment tokens are configured.